import { 	select, 
        	csv, 
        	scaleLinear, 
        	max, 
        	scaleBand, axisLeft, axisBottom, format
       } from 'd3';

const svg = d3.select('svg');

const width  = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const xValue = d => d.population;
  const yValue = d => d.country;
  const margin = { top: 20, right: 50, bottom: 20, left: 100 };
	const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	// setting domain a la linear scale
  	.domain([0, max(data, xValue)])
  	.range([0, innerWidth]);
  
  const yScale = scaleBand()
  	.domain(data.map(yValue))
  	.range([0, innerHeight])
  	.padding(0.1);
    
  // a variable to group svg elements around to add axes
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left},${margin.top})`);
  
  // call to yAxis to tranform g to have yAxis ???
  g.append('g').call(axisLeft(yScale));
  g.append('g').call(axisBottom(xScale))
  	.attr('transform', `translate(0,${innerHeight})`);
  
  // select all rectangles
	svg.selectAll('rect').data(data)
  	.enter().append('rect')
  		.attr('y', d => yScale(yValue(d)))
  		.attr('width', d => xScale(xValue(d)))
  		.attr('height', d => yScale.bandwidth());
}; 

csv('data.csv').then(data => {
  data.forEach(d => {
    // parse string into numbers with +d
  	d.population = +d.population * 1000;
  });
	render(data);
});

